@@ -29,7 +29,6 @@ from typing import List, Dict, Optional, Callable, Type, Union, NamedTuple, Any
 from urllib.parse import urljoin
 import requests
 from qiskit.providers.ibmq.runtime import RuntimeProgram, RuntimeJob, ResultDecoder
-from qiskit.providers.ibmq.runtime.runtime_program import ProgramParameter, ProgramResult
 from qiskit.providers.ibmq.runtime.utils import RuntimeEncoder
 from qiskit.providers import ProviderV1 as Provider
 import logging
@@ -141,14 +140,7 @@ class RemoteRuntimeService():
                         program_metadata = {}
                     self._programs[prog['program_id']] = RuntimeProgram(program_name=prog['name'], 
                                                         program_id=prog['program_id'], 
-                                                        description=program_metadata['description'], 
-                                                        max_execution_time=(int(program_metadata['max_execution_time']) if 'max_execution_time' in program_metadata else 0),
-                                                        parameters=(program_metadata['parameters'] if 'parameters' in program_metadata else None)  ,
-                                                        return_values=(program_metadata['return_values'] if 'return_values' in program_metadata else None),
-                                                        interim_results=(program_metadata['interim_results'] if 'interim_results' in program_metadata else None),
-                                                        version=(program_metadata['version'] if 'version' in program_metadata else "0"),
-                                                        backend_requirements=(program_metadata['backend_requirements'] if 'backend_requirements' in program_metadata else None),
-                                                        creation_date=(program_metadata['creation_date'] if 'creation_date' in program_metadata else ""))
+                                                        **program_metadata)
 
         return self._programs
 
@@ -181,14 +173,6 @@ class RemoteRuntimeService():
             data: Union[bytes, str],
             program_id: Optional[str] = None,
             metadata: Optional[Union[Dict, str]] = None,
-            name: Optional[str] = None,
-            max_execution_time: Optional[int] = None,
-            description: Optional[str] = None,
-            version: Optional[float] = None,
-            backend_requirements: Optional[str] = None,
-            parameters: Optional[List[ProgramParameter]] = None,
-            return_values: Optional[List[ProgramResult]] = None,
-            interim_results: Optional[List[ProgramResult]] = None
     ) -> str:
 
         # We removed this because the orchestrator assigns the actual program ID.
@@ -200,22 +184,18 @@ class RemoteRuntimeService():
         #     if name is None:
         #         name = program_id
 
-        program_metadata = self._merge_metadata(
-            initial={},
-            metadata=metadata,
-            name=name, max_execution_time=max_execution_time, description=description,
-            version=version, backend_requirements=backend_requirements,
-            parameters=parameters,
-            return_values=return_values, interim_results=interim_results)
-        program_metadata.pop('name', None)
 
-        str_metadata = json.dumps(program_metadata)
+        metadata = self._merge_metadata(metadata=metadata)
+
+        prog_name = None if 'name' not in metadata else metadata.pop('name'),
+        print(metadata)
+        str_metadata = json.dumps(metadata)
 
         data_type = STRING
 
         req_body = {
             'data': None,
-            'name': name,
+            'name': prog_name,
             'data_type': data_type,  
             'program_metadata': str_metadata
         }
@@ -301,27 +281,17 @@ class RemoteRuntimeService():
             name: Optional[str] = None,
             max_execution_time: Optional[int] = None,
             description: Optional[str] = None,
-            version: Optional[float] = None,
-            backend_requirements: Optional[str] = None,
-            parameters: Optional[List[ProgramParameter]] = None,
-            return_values: Optional[List[ProgramResult]] = None,
-            interim_results: Optional[List[ProgramResult]] = None
+            spec: Optional[Dict] = None,
     ):
-        program_metadata = self._merge_metadata(
-            initial={},
-            metadata=metadata,
-            name=name, max_execution_time=max_execution_time, description=description,
-            version=version, backend_requirements=backend_requirements,
-            parameters=parameters,
-            return_values=return_values, interim_results=interim_results)
-        program_metadata.pop('name', None)
-        
-        str_metadata = json.dumps(program_metadata)
+        metadata = self._merge_metadata(metadata=metadata, name=name, max_execution_time=max_execution_time, description=description, spec=spec)
+
+        prog_name = None if 'name' not in metadata else metadata.pop('name')
+        str_metadata = json.dumps(metadata)
 
         req_body = {
             'program_id': program_id,
             'data': None,
-            'name': name,
+            'name': prog_name,
             'data_type': None,  
             'program_metadata': str_metadata
         }
@@ -375,52 +345,25 @@ class RemoteRuntimeService():
     # copied from IBM runtime service
     def _merge_metadata(
             self,
-            initial: Dict,
-            metadata: Optional[Union[Dict, str]] = None,
+            metadata: Optional[Dict] = None,
             **kwargs: Any
     ) -> Dict:
         """Merge multiple copies of metadata.
         Args:
-            initial: The initial metadata. This may be mutated.
-            metadata: Name of the program metadata file or metadata dictionary.
+            metadata: Program metadata.
             **kwargs: Additional metadata fields to overwrite.
         Returns:
             Merged metadata.
         """
-        upd_metadata = {}
-        if metadata is not None:
-            if isinstance(metadata, str):
-                with open(metadata, 'r') as file:
-                    upd_metadata = json.load(file)
-            else:
-                upd_metadata = copy.deepcopy(metadata)
-
-        self._tuple_to_dict(initial)
-        initial.update(upd_metadata)
-
-        self._tuple_to_dict(kwargs)
-        for key, val in kwargs.items():
-            if val is not None:
-                initial[key] = val
-
-        # TODO validate metadata format
-        metadata_keys = ['name', 'max_execution_time', 'description', 'version',
-                         'backend_requirements', 'parameters', 'return_values',
-                         'interim_results']
-        return {key: val for key, val in initial.items() if key in metadata_keys}
-
-    def _tuple_to_dict(self, metadata: Dict) -> None:
-        """Convert fields in metadata from named tuples to dictionaries.
-        Args:
-            metadata: Metadata to be converted.
-        """
-        for key in ['parameters', 'return_values', 'interim_results']:
-            doc_list = metadata.pop(key, None)
-            if not doc_list or isinstance(doc_list[0], dict):
-                continue
-            metadata[key] = [dict(elem._asdict()) for elem in doc_list]
-
-
+        merged = {}
+        metadata = metadata or {}
+        metadata_keys = ['name', 'max_execution_time', 'description', 'spec']
+        for key in metadata_keys:
+            if kwargs.get(key, None) is not None:
+                merged[key] = kwargs[key]
+            elif key in metadata.keys():
+                merged[key] = metadata[key]
+        return merged
     def login_with_token(self, access_token):
         token_obj = {
             "token": access_token,
